% Auto-generated chapter 14 for ibnmajah
% Hadiths in this chapter: 15

\hadithdefcmd{ibnmajah}{2375}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ انْطَلَقَ بِهِ أَبُوهُ يَحْمِلُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ اشْهَدْ أَنِّي قَدْ نَحَلْتُ النُّعْمَانَ مِنْ مَالِي كَذَا وَكَذَا ‏.‏ قَالَ ‏"‏ فَكُلَّ بَنِيكَ نَحَلْتَ مِثْلَ الَّذِي نَحَلْتَ النُّعْمَانَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَأَشْهِدْ عَلَى هَذَا غَيْرِي ‏"‏ ‏.‏ قَالَ ‏"‏ أَلَيْسَ يَسُرُّكَ أَنْ يَكُونُوا لَكَ فِي الْبِرِّ سَوَاءً ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{2375}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Nu'man bin Bashir said that his father took him to the Prophet (ﷺ) and said:“Bear witness that I have given Nu'man such and such from my wealth.” He said: “Have you given all your children something like that which you have given to Nu'man?” He said: “No.” He said: “Then let someone other than me bear witness to that.” And he said: “Would you not like all your children to honor you equally?” He said: “Of course.” He said: “Then do not do this.”}}
\hadithdefcmd{ibnmajah}{2376}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، وَمُحَمَّدِ بْنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَخْبَرَاهُ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، نَحَلَهُ غُلاَمًا وَأَنَّهُ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم يُشْهِدُهُ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{2376}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Nu'man bin Bashir that:his father gave him a gift of a slave, and he came to the Prophet (ﷺ) so that he could witness the gift. He said: “Have you given something to all of your children?” He said: “No.” He said: “Then take back (your gift).”}}
\hadithdefcmd{ibnmajah}{2377}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، وَابْنِ، عُمَرَ يَرْفَعَانِ الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِلرَّجُلِ أَنْ يُعْطِيَ الْعَطِيَّةَ ثُمَّ يَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ ‏"‏ ‏.‏\hadithno{2377}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas and Ibn 'Umar, who attributed the Hadith to the Prophet (ﷺ) that he said:“It is not permissible for a man to give a gift then take it back, except what a father gives to his child.”}}
\hadithdefcmd{ibnmajah}{2378}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَرْجِعْ أَحَدُكُمْ فِي هِبَتِهِ إِلاَّ الْوَالِدَ مِنْ وَلَدِهِ ‏"‏ ‏.‏\hadithno{2378}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Amr bin Shu'aib, from his father, from, his Grandfather, that the Prophet (ﷺ) of Allah (SWT) said:“None of you should take back his gift, except a father (taking it back) from his son.”}}
\hadithdefcmd{ibnmajah}{2379}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عُمْرَى فَمَنْ أُعْمِرَ شَيْئًا فَهُوَ لَهُ ‏"‏ ‏.‏\hadithno{2379}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There is no lifelong grant. Whoever is given something as a lifelong grant, it is his.' ”}}
\hadithdefcmd{ibnmajah}{2380}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْمَرَ رَجُلاً عُمْرَى لَهُ وَلِعَقِبِهِ فَقَدْ قَطَعَ قَوْلُهُ حَقَّهُ فِيهَا فَهِيَ لِمَنْ أُعْمِرَ وَلِعَقِبِهِ ‏"‏ ‏.‏\hadithno{2380}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:“I heard the Messenger of Allah (ﷺ) say: 'Whoever gives a lifelong grant to a man, it belongs to him (the recipient) and to his heirs. His (the giver's) words put an end to his right to it, and it belongs to the one to whom it was given for life and to his heirs.”}}
\hadithdefcmd{ibnmajah}{2381}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ الْعُمْرَى لِلْوَارِثِ ‏.‏\hadithno{2381}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Zaid bin Thabit that :the Prophet (ﷺ) ruled that a gift given for life belongs to the heirs (of the recipient)}}
\hadithdefcmd{ibnmajah}{2382}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ رُقْبَى فَمَنْ أُرْقِبَ شَيْئًا فَهُوَ لَهُ حَيَاتَهُ وَمَمَاتَهُ ‏"‏ ‏.‏ قَالَ وَالرُّقْبَى أَنْ يَقُولَ هُوَ لِلآخَرِ مِنِّي وَمِنْكَ مَوْتًا ‏.‏\hadithno{2382}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“There is no Ruqba. Whoever is given a gift on the basis of Ruqba, it belongs to him, whether he lives or dies.”}}
\hadithdefcmd{ibnmajah}{2383}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالاَ حَدَّثَنَا دَاوُدُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى جَائِزَةٌ لِمَنْ أُعْمِرَهَا وَالرُّقْبَى جَائِزَةٌ لِمَنْ أُرْقِبَهَا ‏"‏ ‏.‏\hadithno{2383}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:“Umra belongs to the one to whom it is given, and Ruqba belongs to the one to whom it is given.”}}
\hadithdefcmd{ibnmajah}{2384}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنْ خِلاَسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مَثَلَ الَّذِي يَعُودُ فِي عَطِيَّتِهِ كَمَثَلِ الْكَلْبِ أَكَلَ حَتَّى إِذَا شَبِعَ قَاءَ ثُمَّ عَادَ فِي قَيْئِهِ فَأَكَلَهُ ‏"‏ ‏.‏\hadithno{2384}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The likeness of one who takes back his gift is that of a dog that eats until it is full and vomits; then it goes back to its vomit and eats it again.”}}
\hadithdefcmd{ibnmajah}{2385}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{2385}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“The one who takes back his gift is like the one who goes back to his vomit.”}}
\hadithdefcmd{ibnmajah}{2386}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُوسُفَ الْعَرْعَرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي حَكِيمٍ، حَدَّثَنَا الْعُمَرِيُّ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{2386}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn`Umar that the Prophet (ﷺ) said:“The one who takes back his gift is like the dog that goes back to its vomit.”}}
\hadithdefcmd{ibnmajah}{2387}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ بْنِ مُجَمِّعِ بْنِ جَارِيَةَ الأَنْصَارِيُّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّجُلُ أَحَقُّ بِهِبَتِهِ مَا لَمْ يُثَبْ مِنْهَا ‏"‏ ‏.‏\hadithno{2387}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A man has more right to his gift so long as he has not gotten something in return for it.”}}
\hadithdefcmd{ibnmajah}{2388}{حَدَّثَنَا أَبُو يُوسُفَ الرَّقِّيُّ، مُحَمَّدُ بْنُ أَحْمَدَ الصَّيْدَلاَنِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ الْمُثَنَّى بْنِ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي خُطْبَةٍ خَطَبَهَا ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ فِي مَالِهَا إِلاَّ بِإِذْنِ زَوْجِهَا إِذَا هُوَ مَلَكَ عِصْمَتَهَا ‏"‏ ‏.‏\hadithno{2388}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father that he delivered:“It is not permissible for a woman to dispose of her wealth except with her husband's permission, once he has married her.”}}
\hadithdefcmd{ibnmajah}{2389}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَحْيَى، - رَجُلٌ مِنْ وَلَدِ كَعْبِ بْنِ مَالِكٍ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ جَدَّتَهُ، خَيْرَةَ - امْرَأَةَ كَعْبِ بْنِ مَالِكٍ - أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِحُلِيٍّ لَهَا فَقَالَتْ إِنِّي تَصَدَّقْتُ بِهَذَا فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَجُوزُ لِلْمَرْأَةِ فِي مَالِهَا إِلاَّ بِإِذْنِ زَوْجِهَا فَهَلِ اسْتَأْذَنْتِ كَعْبًا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى كَعْبِ بْنِ مَالِكٍ زَوْجِهَا فَقَالَ ‏"‏ هَلْ أَذِنْتَ لِخَيْرَةَ أَنْ تَتَصَدَّقَ بِحُلِيِّهَا ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَقَبِلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا ‏\hadithno{2389}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Yahya, one of the sons of Ka'b bin Malik, from his grandfather, that :his grandmother Khairah, the wife of Ka'b bin Malik, came to the Messenger of Allah (ﷺ) with some jewelry belonging to her and said, I am giving this in charity. The Messenger of Allah (ﷺ) said to her: “It is not permissible for a woman to dispose of her wealth without her husband's permission. Did you ask Ka'b's permission?” She said: “Yes.” So the Messenger of Allah (ﷺ) sent for Ka'b bin Malik, her husband, and said, “Did you give Khairah permission to give her jewelry in charity?” He said: “Yes.” So the Messenger of Allah (ﷺ) accepted it from her}}
